#!/usr/local/bin/wish8.4 -f
# Requires Tcl/Tk Wish 8.4

#---------------------------------------------------------------
# MODIS Orbit Itinerary Viewer, moi.tcl, version 1.0
# Programmer:	Jordan Gerth, CIMSS/SSEC - Madison, Wisconsin
# Contact:	Via e-mail at jordang@ssec.wisc.edu
# Releases:	July 3, 2007 (initial), July 18, 2007 (modified)
#
# Arguments:	none required, none optional
#
# For:	Displaying anticipated MODIS passes with North American
#  coverage during the present day (images are stored locally)
# Use:	This script creates a simple graphical user interface
#  which produces the aforementioned images, with toggling to
#  switch between the day's orbit itineraries of Aqua and Terra
# WWW:	http://www.ssec.wisc.edu/~jordang/awips-modis/index.html
#
# Error catching:	not implemented
#---------------------------------------------------------------

# Obtain directory where script is installed
global applicdir
set applicdir [file normalize [file dirname $argv0]]

proc makeGui { parent } {
 set env(TZ) GMT
 set date [clock scan now]
 set sixtn 1382400
 set cycdy [expr "$date % $sixtn + 86400"]
 global applicdir dayco pssdy ptday
 set dayco 0
 set pssdy [expr "((($cycdy - ($cycdy % 86400)) / 86400) % 16) + 1"]
 set ptday $pssdy

 label .title -text "Aqua MODIS Orbit Itinerary for Today - Day $pssdy of 16-day Cycle" \
  -foreground white -background black
 pack .title -side top -anchor center

 global orbit modorb
 set orbit [image create photo -file $applicdir/orbits/Aqua/$pssdy.gif]

 label .imagedisp -image $orbit
 pack .imagedisp -side top -anchor center
 
 frame .modis -borderwidth 2 -relief groove -pady 3
 radiobutton .modis.aqua -font "10x20" -text "Aqua" -variable modorb \
  -value "Aqua" -command {dispnew Aqua}
 radiobutton .modis.terra -font "10x20" -text "Terra" -variable modorb \
  -value "Terra" -command {dispnew Terra}
 .modis.aqua select
 grid .modis.aqua -in .modis -row 1 -column 1
 grid .modis.terra -in .modis -row 1 -column 2
 pack .modis -side left

 button .bckwrd -font "10x20" -text "Backward" -command {prev}
 button .today -font "10x20" -text "Today" -command {tday}
 button .forwrd -font "10x20" -text "Forward" -command {next}
 button .close -font "10x20" -text "Exit" -command {exit}
 pack .close .forwrd .today .bckwrd -side right -pady 4

 label .imday -text [exec date -u "+%A, %B %e, %Y (UTC)"]
 label .uc -text "University of Wisconsin - Madison" -foreground white -background red 
 pack .uc .imday -side bottom -pady 2
}

proc prev { } {
 global dayco modorb pssdy
 set dayco [expr "$dayco + 1"]
 set pssdy [expr "$pssdy - 1"]
 if {$pssdy < 1} {set pssdy 16}
 dispnew $modorb
}

proc tday { } {
 global dayco modorb pssdy ptday
 set dayco 0
 set pssdy $ptday
 dispnew $modorb
}

proc next { } {
 global dayco modorb pssdy
 set dayco [expr "$dayco - 1"]
 set pssdy [expr "$pssdy + 1"]
 if {$pssdy > 16} {set pssdy 1}
 dispnew $modorb
}

proc dispnew { sat } {
 global applicdir dayco orbit pssdy
 $orbit blank
 $orbit read $applicdir/orbits/$sat/$pssdy.gif
 .imday configure -text [exec date -u -d "$dayco days ago" "+%A, %B %e, %Y (UTC)"]
 if {$dayco != 0} {
  .title configure -text "Upcoming $sat MODIS Orbit Itinerary for Day $pssdy of 16-day Cycle"
 } else {.title configure -text "$sat MODIS Orbit Itinerary for Today - Day $pssdy of 16-day Cycle"}
}
 
wm resizable . 0 0
wm title . "MODIS Orbit Itinerary Viewer v1.0 from CIMSS/SSEC"

makeGui {}
